django-mama-cas documentation — django-mama-cas 0.2 documentation

### Navigation

- index
- modules |
- next |
- django-mama-cas 0.2 documentation »

# django-mama-cas documentation

django-mama-cas is a Python implementation of the Central Authentication Service (CAS) server protocol, providing single sign-on server functionality as a Django application. It implements the current CAS specification to handle CAS authentication and validation requests.

CAS is an HTTP-based protocol that provides single sign-on functionality to web services. It operates using tickets, unique text strings that are provided and validated by the server, allowing web services to authenticate a user without having access to the user’s credentials. The protocol page has more information about CAS and this implementation of it.

Most likely, you’d like to know how to get started.

You might also be interested in what’s changed.

## Contents

- Getting started
- Changelog
- Templates
- Management commands
- Forms
- CAS protocol

### Navigation

- index
- modules |
- next |
- django-mama-cas 0.2 documentation »